<?php
require_once 'SebastianBergmann/CodeCoverage/autoload.php';
require_once __DIR__ . '/../tests/src/SourceAnalyserTestCase.php';
require_once __DIR__ . '/../tests/src/TestCase.php';
require_once __DIR__ . '/../tests/_files/BankAccountTest.php';
require_once __DIR__ . '/../tests/_files/CoveredClass.php';
require_once __DIR__ . '/../tests/_files/Target/TraitOne.php';
